@@ -5,7 +5,7 @@ class Environment(object):
         # Production
         if not sandbox:
             self.api = 'https://plugboleto.com.br/api/v1/'
-            self.apidoc = 'https://apis.grupolinsferrao.com.br/api-numerodoc-plugboleto/'
+            self.apidoc = 'http://apis.grupolinsferrao.com.br/api-numerodoc-plugboleto/'
         else:
             self.api = 'http://homologacao.plugboleto.com.br/api/v1/'
-            self.apidoc = 'https://apis-sandbox.grupolinsferrao.com.br/api-numerodoc-plugboleto/'
\ No newline at end of file
+            self.apidoc = 'http://apis-sandbox.grupolinsferrao.com.br/api-numerodoc-plugboleto/'
\ No newline at end of file
