@@ -1,6 +1,8 @@
-import uuid, json
+import uuid
+import json
 from requests import Request, Session
 
+
 class Base(object):
 
     def __init__(self, authorize):
@@ -42,15 +44,8 @@ class Base(object):
             }]
 
         if response.status_code >= 400:
-            errors = []
-
-            for answer in answers:
-                errors.append('\r\n * [%s] %s\r\n' % (answer['Code'], answer['Message']))
-
-            data_send = json.loads(body or 'null')
-
-            raise Exception('\r\n%s\r\nMethod: %s\r\nUri: %s\r\nData: %s' % (
-            ''.join(errors), method, response.url, json.dumps(data_send, indent=2)))
+            errors = response.json()
+            raise Exception(errors)
 
         return answers, body
 
@@ -83,6 +78,6 @@ class Base(object):
             data_send = json.loads(body or 'null')
 
             raise Exception('\r\n%s\r\nMethod: %s\r\nUri: %s\r\nData: %s' % (
-            ''.join(errors), method, response.url, json.dumps(data_send, indent=2)))
+                ''.join(errors), method, response.url, json.dumps(data_send, indent=2)))
 
         return answers
