@@ -2,6 +2,7 @@
 from .base import Base
 import json
 
+
 class CriarBoleto(Base):
 
     def __init__(self, authorize, environment):
@@ -21,7 +22,5 @@ class CriarBoleto(Base):
         sucesso = response[0]['_dados']['_sucesso']
         if sucesso:
             criar_boleto.update_return(response[0], body)
-        else:
-            return response[0]['_dados']['_falha']
 
         return response
